.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2017-12-31)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.1.0...v0.2.0)>`_

* Added syncing of database with online HPO resources.

0.3.0 (2017-01-02)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.2.0...v0.3.0)>`_

* Added Disease genes model and REST API.
* Synced Disease genes from online HPO resource.

0.3.1 (2017-01-04)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.3.0...v0.3.1)>`_

* Fixed minor bugs
* Added better test coverage for hpo_sync.

0.4.0 (2017-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.3.1...v0.4.0)>`_

* Improved REST API filters.

0.4.1 (2017-01-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.4.0...v0.4.1)>`_

* Fixed issues with migrations.

0.4.2 (2017-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.4.1...v0.4.2)>`_

* Fixed route names for SimpleRouter.

0.5.0 (2017-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-hpo-terms/compare/v0.4.2...v0.5.0)>`_

* Add gene symbol filter for diseases API
* Added HPO term label to disease API
* updated requirements to the latest
